# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.share_api import ShareApi


class TestShareApi(unittest.TestCase):
    """ShareApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShareApi()

    def tearDown(self) -> None:
        pass

    def test_access(self) -> None:
        """Test case for access

        """
        pass

    def test_create_share_name(self) -> None:
        """Test case for create_share_name

        """
        pass

    def test_delete_share_name(self) -> None:
        """Test case for delete_share_name

        """
        pass

    def test_list_all_names(self) -> None:
        """Test case for list_all_names

        """
        pass

    def test_list_names_for_namespace(self) -> None:
        """Test case for list_names_for_namespace

        """
        pass

    def test_list_share_namespaces(self) -> None:
        """Test case for list_share_namespaces

        """
        pass

    def test_share(self) -> None:
        """Test case for share

        """
        pass

    def test_unaccess(self) -> None:
        """Test case for unaccess

        """
        pass

    def test_unshare(self) -> None:
        """Test case for unshare

        """
        pass

    def test_update_access(self) -> None:
        """Test case for update_access

        """
        pass

    def test_update_share(self) -> None:
        """Test case for update_share

        """
        pass

    def test_update_share_name(self) -> None:
        """Test case for update_share_name

        """
        pass


if __name__ == '__main__':
    unittest.main()
