# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.shares_list import SharesList

class TestSharesList(unittest.TestCase):
    """SharesList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharesList:
        """Test SharesList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharesList`
        """
        model = SharesList()
        if include_optional:
            return SharesList(
                shares = [
                    zrok_api.models.share_summary.shareSummary(
                        share_token = '', 
                        z_id = '', 
                        env_zid = '', 
                        share_mode = '', 
                        backend_mode = '', 
                        frontend_endpoints = [
                            ''
                            ], 
                        target = '', 
                        limited = True, 
                        created_at = 56, 
                        updated_at = 56, )
                    ]
            )
        else:
            return SharesList(
        )
        """

    def testSharesList(self):
        """Test SharesList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
