# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AccessSummary(BaseModel):
    """
    AccessSummary
    """ # noqa: E501
    id: Optional[StrictInt] = None
    frontend_token: Optional[StrictStr] = Field(default=None, alias="frontendToken")
    env_zid: Optional[StrictStr] = Field(default=None, alias="envZId")
    share_token: Optional[StrictStr] = Field(default=None, alias="shareToken")
    backend_mode: Optional[StrictStr] = Field(default=None, alias="backendMode")
    bind_address: Optional[StrictStr] = Field(default=None, alias="bindAddress")
    description: Optional[StrictStr] = None
    limited: Optional[StrictBool] = None
    created_at: Optional[StrictInt] = Field(default=None, alias="createdAt")
    updated_at: Optional[StrictInt] = Field(default=None, alias="updatedAt")
    __properties: ClassVar[List[str]] = ["id", "frontendToken", "envZId", "shareToken", "backendMode", "bindAddress", "description", "limited", "createdAt", "updatedAt"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccessSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccessSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "frontendToken": obj.get("frontendToken"),
            "envZId": obj.get("envZId"),
            "shareToken": obj.get("shareToken"),
            "backendMode": obj.get("backendMode"),
            "bindAddress": obj.get("bindAddress"),
            "description": obj.get("description"),
            "limited": obj.get("limited"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt")
        })
        return _obj


